## ----style, echo = FALSE, results = 'asis'---------------------------------
BiocStyle::markdown(css.files = c('custom.css'))

## ---- echo=FALSE-----------------------------------------------------------
suppressPackageStartupMessages(
  library(tRNAdbImport)
)

## ----eval=FALSE------------------------------------------------------------
#  library(tRNAdbImport)

## --------------------------------------------------------------------------
# accessing tRNAdb
# tRNA from yeast for Alanine and Phenylalanine
gr <- import.tRNAdb(organism = "Saccharomyces cerevisiae",
                    aminoacids = c("Phe","Ala"))

## --------------------------------------------------------------------------
# get a Phenylalanine tRNA from yeast
gr <- import.tRNAdb.id(tdbID = gr[gr$tRNA_type == "Phe",][1]$tRNAdb_ID)

## --------------------------------------------------------------------------
# find the same tRNA via blast
gr <- import.tRNAdb.blast(blastSeq = gr$tRNA_seq)

## --------------------------------------------------------------------------
# accessing mtRNAdb
# get the mitochrondrial tRNA for Alanine in Bos taurus
gr <- import.mttRNAdb(organism = "Bos taurus", 
                      aminoacids = "Ala")

## --------------------------------------------------------------------------
# get one mitochrondrial tRNA in Bos taurus. 
gr <- import.mttRNAdb.id(mtdbID = gr[1]$tRNAdb_ID)

## --------------------------------------------------------------------------
# check that the result has the appropriate columns
istRNAdbGRanges(gr)

## --------------------------------------------------------------------------
gr <- import.tRNAdb(organism = "Saccharomyces cerevisiae",
                    aminoacids = c("Phe","Ala"),
                    database = "RNA")
gr$tRNA_seq

## --------------------------------------------------------------------------
separate(gr$tRNA_seq)

## ---- echo=FALSE-----------------------------------------------------------
suppressPackageStartupMessages({
  library(Biostrings)
  library(rtracklayer)
})

## --------------------------------------------------------------------------
library(Biostrings)
library(rtracklayer)
writeXStringSet(gr$tRNA_seq, filepath = tempfile())
gff <- tRNAdb2GFF(gr)
export.gff3(gff, con = tempfile())

## --------------------------------------------------------------------------
sessionInfo()

